==> apache-nuttx-apps-12.5.0.tar.gz: apps/testing/testsuites/kernel/pthread/common/test_pthread_common.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/pthread/common/test_pthread_common.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <stdio.h>
#include <sys/stat.h>
#include <dirent.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <cmocka.h>
#include <syslog.h>
#include <errno.h>
#include <stdlib.h>
#include "PthreadTest.h"

UINT32 g_test_pthread_count;
UINT32 g_test_pthread_task_max_num = 128;

/****************************************************************************
 * Private Functions
 ****************************************************************************/

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: TestPthreadSelf
 ****************************************************************************/

pthread_t test_pthread_self(void)
{
  pthread_t tid = pthread_self();
  return tid;
}

/****************************************************************************
 * Name: TestNuttxSyscallTestGroupTearDown
 ****************************************************************************/

==> apache-nuttx-apps-12.9.0.tar.gz: apps/testing/testsuites/kernel/pthread/common/test_pthread_common.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/pthread/common/test_pthread_common.c
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/
#include <nuttx/config.h>
#include <stdio.h>
#include <sys/stat.h>
#include <dirent.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <cmocka.h>
#include <syslog.h>
#include <errno.h>
#include <stdlib.h>
#include "PthreadTest.h"

UINT32 g_testpthreadcount;
UINT32 g_testpthreadtaskmaxnum = 128;
/****************************************************************************
 * Private Functions
 ****************************************************************************/

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: testpthreadself
 ****************************************************************************/

pthread_t testpthreadself(void)
{
  pthread_t tid = pthread_self();
  return tid;
}

/****************************************************************************
 * Name: TestNuttxSyscallTestGroupTearDown
 ****************************************************************************/
